full_moon::ast

Struct While

pub struct While { /* private fields */ }
A while loop

Implementations

Source

impl While

pub fn new(condition: Expression) -> Self

Creates a new While from the given condition

pub fn while_token(&self) -> &TokenReference

The while token

pub fn condition(&self) -> &Expression

The condition part of while condition do

pub fn do_token(&self) -> &TokenReference

The do token

pub fn block(&self) -> &Block

The code inside the while loop

pub fn end_token(&self) -> &TokenReference

The end token

pub fn with_while_token(self, while_token: TokenReference) -> Self

Returns a new While with the given while token

pub fn with_condition(self, condition: Expression) -> Self

Returns a new While with the given condition

pub fn with_do_token(self, do_token: TokenReference) -> Self

Returns a new While with the given do token

pub fn with_block(self, block: Block) -> Self

Returns a new While with the given block

pub fn with_end_token(self, end_token: TokenReference) -> Self

Returns a new While with the given end token